<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<!-- without this the indexes of arrays break -->
	<xsl:strip-space elements="*"/>
	<xsl:template match="RVPresentationDocument/@versionNumber">
		<xsl:attribute name="versionNumber">500</xsl:attribute>
	</xsl:template>
	<xsl:template match="RVPresentationDocument/@CCLIArtistCredits">
		<xsl:attribute name="CCLIArtistCredits"/>
		<xsl:attribute name="album"/>
		<xsl:attribute name="artist">
			<xsl:value-of select="."/>
		</xsl:attribute>
		<xsl:attribute name="creatorCode">
			<xsl:value-of select="1349676880"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="RVPresentationDocument/@CCLIAuthor">
		<xsl:attribute name="author">
			<xsl:value-of select="."/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="RVPresentationDocument/@CCLISongNumber">
		<xsl:attribute name="CCLILicenseNumber">
			<xsl:value-of select="."/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="RVPresentationDocument/@CCLICopyrightYear">
		<xsl:attribute name="CCLICopyrightInfo">
			<xsl:value-of select="."/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template match="RVPresentationDocument/@selectedArrangementID"/>
    <xsl:template match="RVPropCue"/>
    <xsl:template match="RVMaskCue"/>
    <xsl:template match="RVMessageCue"/>

<!-- convert: RVRect3D to _-RVRect3D-_position -->
	<xsl:template match="RVRect3D">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="_-RVRect3D-_position">
			<xsl:variable name="xsubstring" select="substring-after(.,'{')"/>
			<xsl:variable name="x" select="substring-before($xsubstring,' ')"/>
			<xsl:variable name="ysubstring" select="substring-after(.,' ')"/>
			<xsl:variable name="y" select="substring-before($ysubstring,' ')"/>
			<xsl:variable name="zsubstring" select="substring-after($ysubstring,' ')"/>
			<xsl:variable name="z" select="substring-before($zsubstring,' ')"/>
			<xsl:variable name="wsubstring" select="substring-after($zsubstring,' ')"/>
			<xsl:variable name="w" select="substring-before($wsubstring,' ')"/>
			<xsl:variable name="hsubstring" select="substring-after($wsubstring,' ')"/>
			<xsl:variable name="h" select="substring-before($hsubstring,'}')"/>
			<xsl:attribute name="x">
				<xsl:value-of select="$x"/>
			</xsl:attribute>
			<xsl:attribute name="y">
				<xsl:value-of select="$y"/>
			</xsl:attribute>
			<xsl:attribute name="z">
				<xsl:value-of select="$z"/>
			</xsl:attribute>
			<xsl:attribute name="width">
				<xsl:value-of select="$w"/>
			</xsl:attribute>
			<xsl:attribute name="height">
				<xsl:value-of select="$h"/>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>
	<!-- convert shadow element to serializedShadow dictionary-->
	<xsl:template match="shadow">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:variable name="shadowBlurRadius" select="substring-before(.,'|')"/>
		<xsl:variable name="substring" select="substring-after(.,'|')"/>
		<xsl:variable name="shadowColor" select="substring-before($substring,'|')"/>
		<xsl:variable name="shadowOffset" select="substring-after($substring,'|')"/>
		<xsl:element name="_-D-_serializedShadow">
			<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
<!-- 
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
 -->
			<xsl:element name="NSNumber">
				<xsl:attribute name="serialization-native-value">
					<xsl:value-of select="$shadowBlurRadius"/>
				</xsl:attribute>
				<xsl:attribute name="serialization-dictionary-key">shadowBlurRadius</xsl:attribute>
			</xsl:element>
			<xsl:element name="NSColor">
				<xsl:attribute name="serialization-native-value">
					<xsl:value-of select="$shadowColor"/>
				</xsl:attribute>
				<xsl:attribute name="serialization-dictionary-key">shadowColor</xsl:attribute>
			</xsl:element>
			<xsl:element name="NSMutableString">
				<xsl:attribute name="serialization-native-value">
					<xsl:value-of select="$shadowOffset"/>
				</xsl:attribute>
				<xsl:attribute name="serialization-dictionary-key">shadowOffset</xsl:attribute>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template match="RVSlideTimerCue">
		<xsl:element name="RVControlCue">
			<xsl:attribute name="UUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="displayName">
				<xsl:value-of select="./@displayName"/>
			</xsl:attribute>
			<xsl:attribute name="delayTime">
				<xsl:value-of select="./@delayTime"/>
			</xsl:attribute>
			<xsl:attribute name="timeStamp">
				<xsl:value-of select="./@timeStamp"/>
			</xsl:attribute>
			<xsl:attribute name="enabled">
				<xsl:value-of select="./@enabled"/>
			</xsl:attribute>
			<xsl:attribute name="parentUUID"/>
			<xsl:attribute name="slideUUID"/>
			<xsl:attribute name="slideIndex">-1</xsl:attribute>
			<xsl:attribute name="filePath"/>
			<xsl:attribute name="serialization-array-index">
				<xsl:value-of select="position()-1"/>
			</xsl:attribute>
			<xsl:element name="controlObject">
				<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">Timer</xsl:attribute>
					<xsl:attribute name="serialization-native-value">
						<xsl:value-of select="./@duration"/>
					</xsl:attribute>
				</xsl:element>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">LoopToBeginning</xsl:attribute>
					<xsl:choose>
						<xsl:when test="./@loopToBeginning='true'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="1"/>
							</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="0"/>
							</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="RVTimelineCue">
		<xsl:element name="RVControlCue">
			<xsl:attribute name="UUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="displayName">Slide</xsl:attribute>
			<xsl:attribute name="delayTime">
				<xsl:value-of select="./@delayTime"/>
			</xsl:attribute>
			<xsl:attribute name="timeStamp">
				<xsl:value-of select="./@timeStamp"/>
			</xsl:attribute>
			<xsl:attribute name="enabled">
				<xsl:value-of select="./@enabled"/>
			</xsl:attribute>
			<xsl:attribute name="parentUUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="slideUUID">
				<xsl:value-of select="./@representedObjectUUID"/>
			</xsl:attribute>
			<xsl:attribute name="slideIndex">-1</xsl:attribute>
			<xsl:attribute name="filePath"/>
			<xsl:attribute name="serialization-array-index">
				<xsl:value-of select="position()-1"/>
			</xsl:attribute>
			<xsl:element name="controlObject">
				<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">UUID</xsl:attribute>
					<xsl:attribute name="serialization-native-value">
						<xsl:value-of select="./@representedObjectUUID"/>
					</xsl:attribute>
				</xsl:element>
                <xsl:element name="NSNumber">
                        <xsl:attribute name="serialization-native-value">
                        <xsl:value-of select="./@slideIndex"/>
                        </xsl:attribute>
                        <xsl:attribute name="serialization-dictionary-key">slide_index</xsl:attribute>
                </xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="RVStageDisplayCue"/>
	<xsl:template match="RVLiveVideoCue">
		<xsl:element name="RVControlCue">
			<xsl:attribute name="UUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="displayName">
				<xsl:value-of select="./@displayName"/>
			</xsl:attribute>
			<xsl:attribute name="timeStamp">0</xsl:attribute>
			<xsl:attribute name="delayTime">0</xsl:attribute>
			<xsl:attribute name="parentUUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="slideUUID"/>
			<xsl:attribute name="slideIndex">-1</xsl:attribute>
			<xsl:attribute name="filePath"/>
			<xsl:choose>
				<xsl:when test="./@enabled='true'">
					<xsl:attribute name="enabled">
						<xsl:value-of select="1"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="enabled">
						<xsl:value-of select="0"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:attribute name="serialization-array-index">
				<xsl:value-of select="position()-1"/>
			</xsl:attribute>
			<xsl:element name="controlObject">
				<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">Action</xsl:attribute>
					<xsl:attribute name="serialization-native-value">
						<xsl:value-of select="6"/>
					</xsl:attribute>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="RVMultiScreenCue">
		<xsl:element name="RVControlCue">
			<xsl:attribute name="UUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="displayName">
				<xsl:value-of select="./@displayName"/>
			</xsl:attribute>
			<xsl:attribute name="timeStamp">0</xsl:attribute>
			<xsl:attribute name="delayTime">0</xsl:attribute>
			<xsl:attribute name="parentUUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="slideUUID"/>
			<xsl:attribute name="slideIndex">-1</xsl:attribute>
			<xsl:attribute name="filePath"/>
			<xsl:choose>
				<xsl:when test="./@enabled='true'">
					<xsl:attribute name="enabled">
						<xsl:value-of select="1"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="enabled">
						<xsl:value-of select="0"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:attribute name="serialization-array-index">
				<xsl:value-of select="position()-1"/>
			</xsl:attribute>
			<xsl:element name="controlObject">
				<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">SelectionIndex</xsl:attribute>
					<xsl:attribute name="serialization-native-value">
						<xsl:value-of select="./@layoutIndex"/>
					</xsl:attribute>
				</xsl:element>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">Action</xsl:attribute>
					<xsl:attribute name="serialization-native-value">
						<xsl:value-of select="7"/>
					</xsl:attribute>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="RVTimerCue"/>
	<xsl:template match="RVClearCue[@actionType='1']"/>
	<xsl:template match="RVClearCue">
		<xsl:element name="RVControlCue">
			<xsl:attribute name="UUID">
				<xsl:value-of select="./@UUID"/>
			</xsl:attribute>
			<xsl:attribute name="displayName">
				<xsl:value-of select="./@displayName"/>
			</xsl:attribute>
			<xsl:attribute name="timeStamp">0</xsl:attribute>
			<xsl:attribute name="delayTime">0</xsl:attribute>
			<xsl:attribute name="parentUUID"/>
			<xsl:attribute name="slideUUID"/>
			<xsl:attribute name="slideIndex">-1</xsl:attribute>
			<xsl:attribute name="filePath"/>
			<xsl:choose>
				<xsl:when test="./@enabled='true'">
					<xsl:attribute name="enabled">
						<xsl:value-of select="1"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="enabled">
						<xsl:value-of select="0"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:attribute name="serialization-array-index">
				<xsl:value-of select="position()-1"/>
			</xsl:attribute>
			<xsl:element name="controlObject">
				<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
				<xsl:element name="NSMutableString">
					<xsl:attribute name="serialization-dictionary-key">Action</xsl:attribute>
					<xsl:choose>
						<!-- Clear All -->
						<xsl:when test="./@actionType='0'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="0"/>
							</xsl:attribute>
						</xsl:when>
						<!-- Clear Slide (doesn't exist on Pro5, will be matched separately) -->
						<xsl:when test="./@actionType='1'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="0"/>
							</xsl:attribute>
						</xsl:when>
						<!-- Clear Background -->
						<xsl:when test="./@actionType='2'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="1"/>
							</xsl:attribute>
						</xsl:when>
						<!-- Clear Audio -->
						<xsl:when test="./@actionType='3'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="2"/>
							</xsl:attribute>
						</xsl:when>
						<!-- Clear Props -->
						<xsl:when test="./@actionType='4'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="3"/>
							</xsl:attribute>
						</xsl:when>
						<!-- Clear Live Video -->
						<xsl:when test="./@actionType='5'">
							<xsl:attribute name="serialization-native-value">
								<xsl:value-of select="5"/>
							</xsl:attribute>
						</xsl:when>
					</xsl:choose>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- Remove Effects -->
    <xsl:template match="array[@rvXMLIvarName='effects'] "/>
    <!-- Convert Arrays -->
	<xsl:template match="array">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="{./@rvXMLIvarName}">
			<xsl:attribute name="containerClass">NSMutableArray</xsl:attribute>
			<xsl:apply-templates select="@*[not(name()='rvXMLIvarName') and not(name()='containerClass')]"/>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:if test="./@rvXMLIvarName='cues'">
				<xsl:apply-templates select="../RVMediaCue" mode="orphanedRVMediaCue"/>
			</xsl:if>
			<xsl:apply-templates select="node()">
				<xsl:with-param name="includeArrayIndexParam" select="true"/>
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>

	<!-- Convert Dictionaries -->
	<xsl:template match="dictionary">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="{./@rvXMLIvarName}">
			<xsl:attribute name="containerClass">NSMutableDictionary</xsl:attribute>
			<xsl:apply-templates select="@*[not(name()='rvXMLIvarName') and not(name()='containerClass')]"/>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="node()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="RVTimeline">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="timeline">
			<xsl:apply-templates select="@*[not(name()='rvXMLIvarName') and not(name()='timeOffset')]"/>
			<xsl:attribute name="timeOffSet">
				<xsl:value-of select="@timeOffset"/>
			</xsl:attribute>
			<xsl:attribute name="unitOfMeasure">
				<xsl:value-of select="30"/>
			</xsl:attribute>
			<xsl:apply-templates select="node()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="RVTextElement">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="RVTextElement">
			<xsl:apply-templates select="@*[not(name()='opacity') and not(name()='UUID')]"/>
			<xsl:attribute name="RTFData">
				<xsl:value-of select="./NSString[@rvXMLIvarName='RTFData']"/>
			</xsl:attribute>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="node()[not(name()='NSString')]"/>
		</xsl:element>
	</xsl:template>
    <xsl:template match="RVSlideGrouping/@hotKey"/>
    <xsl:template match="RVImageElement|RVVideoElement|RVLiveVideoElement">
        <xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:copy>
			<xsl:attribute name="scaleFactor">0</xsl:attribute>
			<xsl:attribute name="serializedImageOffset">0@0</xsl:attribute>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="@*[local-name()!='scaleSize' and local-name()!='imageOffset'] | node()"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="*[substring(name(), string-length(name()) - 6) = 'Element']/RVTransition"/>
	<xsl:template match="RVTransition">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="_-RVProTransitionObject-_transitionObject">
			<xsl:apply-templates select="@*[not(name()='orderIndex') and not(name()='rvXMLIvarName') and not(name()='slideBuildAction') and not(name()='rvXMLIvarName') and not(name()='slideBuildDelay') and not(name()='transitionDirection')]"/>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="node()"/>
		</xsl:element>
	</xsl:template>
	<!-- NSString -->
	<xsl:template match="NSString">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:element name="NSMutableString">
			<xsl:attribute name="serialization-native-value">
				<xsl:value-of select="."/>
			</xsl:attribute>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
		</xsl:element>
	</xsl:template>
    
    <!-- NSURL -->
    <xsl:template match="NSURL">
        <xsl:param name="includeArrayIndexParam">false</xsl:param>
        <xsl:element name="NSURL">
            <xsl:attribute name="serialization-native-value">
                <xsl:value-of select="."/>
            </xsl:attribute>
            <xsl:if test="not($includeArrayIndexParam='false')">
                <xsl:attribute name="serialization-array-index">
                    <xsl:value-of select="position()-1"/>
                </xsl:attribute>
            </xsl:if>
        </xsl:element>
    </xsl:template>
    
	<!-- NSNumber|NSMutableString|NSColor -->
	<xsl:template match="NSNumber|NSMutableString|NSColor">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:copy>
			<!-- <xsl:copy-of select="@*[not(name()='rvXMLDictionaryKey')]"/> -->
			<xsl:choose>
				<xsl:when test="./@rvXMLDictionaryKey">
					<xsl:attribute name="serialization-dictionary-key">
						<xsl:value-of select="./@rvXMLDictionaryKey"/>
					</xsl:attribute>
				</xsl:when>
			</xsl:choose>
			<xsl:attribute name="serialization-native-value">
				<xsl:value-of select="."/>
			</xsl:attribute>
			<xsl:if test="not($includeArrayIndexParam='false')">
				<xsl:attribute name="serialization-array-index">
					<xsl:value-of select="position()-1"/>
				</xsl:attribute>
			</xsl:if>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="@rvXMLDictionaryKey">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:attribute name="serialization-dictionary-key">
			<xsl:value-of select="."/>
		</xsl:attribute>
		<xsl:apply-templates/>
	</xsl:template>
	<!-- remove @rvXMLClassName attributes where necessary -->
	<!-- 	<xsl:template match="RVMediaCue/element/@rvXMLClassName"/> -->
	<xsl:template match="RVDispatchCue/payload/@rvXMLClassName"/>
	<!-- clear out unused attributes -->
    <xsl:template match="RVPlaylistNode/@hotFolderType"/>
    <xsl:template match="RVVideoElement/@fieldType"/>
	<xsl:template match="RVMediaCue/@tags"/>
	<xsl:template match="RVMediaCue/@actionType"/>
	<xsl:template match="RVMediaCue/@playbackBehavior"/>
	<xsl:template match="RVMediaCue/@nextCueUUID"/>
	<xsl:template match="RVMediaCue/@rvXMLIvarName"/>
	<xsl:template match="RVMediaCue/@selected"/>
	<xsl:template match="RVMediaCue/@dateAdded"/>
	<xsl:template match="RVMediaCue/*[substring(name(), string-length(name()) - 6) = 'Element']">
		<xsl:element name="element">
			<xsl:apply-templates select="node()|@*[not(name()='rvXMLIvarName') and not(name()='UUID') and not(name()='naturalSize') and not(name()='opacity') and not(name()='frameRate') and not(name()='imageOffset') and not(name()='scaleSize')]"/>
		</xsl:element>
	</xsl:template>
	<!-- Pass Everything Else Through -->
	<!-- Handle the general attribute template separately from node() so we can convert true/false values into 1/0 -->
	<xsl:template match="@*" name="anyAttribute">
		<xsl:variable name="attributeName" select="name()"/>
		<xsl:attribute name="{$attributeName}">
			<xsl:choose>
				<xsl:when test=".='false'">
					<xsl:text>0</xsl:text>
				</xsl:when>
				<xsl:when test=".='true'">
					<xsl:text>1</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>
	<!-- Finally, the generic node match -->
	<xsl:template match="node()" name="anyNode">
		<xsl:param name="includeArrayIndexParam">false</xsl:param>
		<xsl:choose>
			<xsl:when test="./@rvXMLClassName and not(./@rvXMLClassName='RVTimeline') and not(./@rvXMLClassName='RVVideoElement') and not(./@rvXMLClassName='RVAudioElement')">
				<xsl:variable name="classname" select="./@rvXMLClassName"/>
				<xsl:element name="{concat('_-',$classname,'-_',name())}">
					<xsl:apply-templates select="@*[not(name()='rvXMLClassName')]"/>
					<xsl:if test="not($includeArrayIndexParam='false')">
						<xsl:attribute name="serialization-array-index">
							<xsl:value-of select="position()-1"/>
						</xsl:attribute>
					</xsl:if>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*"/>
					<xsl:if test="not($includeArrayIndexParam='false')">
						<xsl:attribute name="serialization-array-index">
							<xsl:value-of select="position()-1"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:if test="name()=RVMediaCue">
						<xsl:attribute name="elementClassName">
							<xsl:value-of select="name(./*[substring(name(), string-length(name()) - 6) = 'Element'])"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates select="node()"/>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="node()|@*" mode="orphanedRVMediaCue">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:attribute name="serialization-array-index">
				<xsl:value-of select="position()-1"/>
			</xsl:attribute>
			<xsl:attribute name="elementClassName">
				<xsl:value-of select="name(./*[substring(name(), string-length(name()) - 6) = 'Element'])"/>
			</xsl:attribute>
			<xsl:apply-templates select="node()"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="RVDisplaySlide/RVMediaCue"/>
</xsl:stylesheet>
